@@ -8,8 +8,6 @@ use Text::Context;
 use HTML::Strip;
 use Data::Page;
 use Data::Dumper;
-use Readonly;
-Readonly my $EMPTY_STRING => '';
 
 =head1 NAME
 
@@ -20,7 +18,7 @@ MojoMojo::Controller::Page - Page controller
 =head1 DESCRIPTION
 
 This controller is the main juice of MojoMojo. it handles all the
-actions related to wiki pages. actions are redispatched to this
+actions related to wiki pages. Actions are redispatched to this
 controller based on a Regex controller in the main MojoMojo class.
 
 Every private action here expects to have a page path in args. They
@@ -30,8 +28,8 @@ can be called with urls like "/page1/page2.action".
 
 =head2  view (.view)
 
-This is probably the most common action in MojoMojo. A lot of the 
-other actions redispatches to this one. It will prepare the stash 
+This is probably the most common action in MojoMojo. A lot of the
+other actions redispatch to this one. It will prepare the stash
 for page view, and set the template to view.tt, unless another is
 already set.
 
@@ -62,8 +60,7 @@ sub view : Global {
     my $page = $stash->{'page'};
 
     my $user;
-
-    if ( $c->config->{'permissions'}->{'check_permission_on_view'} ) {
+    if ( $c->pref('check_permission_on_view') ) {
         if ( $c->user_exists() ) { $user = $c->user->obj; }
         $c->log->info('Checking permissions') if $c->debug;
 
@@ -107,7 +104,7 @@ sub view : Global {
 
 =head2 search (.search)
 
-This action is called as .search on the current page when the user 
+This action is called as .search on the current page when the user
 performs a search.  The user can choose whether or not to search
 the entire site or a subtree starting from the current page.
 
@@ -122,9 +119,8 @@ sub search : Global {
     my $results_per_page = 10;
 
     my $page = $c->stash->{page};
-    $stash->{template} = 'page/search.tt';
 
-    my $q           = $c->req->params->{q}           || $c->stash->{query};
+    my $q           = $c->req->params->{q}           || $c->stash->{query} || q();
     my $search_type = $c->req->params->{search_type} || "subtree";
     $stash->{query}       = $q;
     $stash->{search_type} = $search_type;
@@ -151,7 +147,7 @@ sub search : Global {
 
         # skip search result depending on permissions
         my $user;
-        if ( $c->config->{'permissions'}{'check_permission_on_view'} ) {
+        if ( $c->pref('check_permission_on_view') ) {
             if ( $c->user_exists() ) { $user = $c->user->obj; }
             my $perms = $c->check_permissions( $page->path, $user );
             next unless $perms->{'view'};
@@ -171,27 +167,18 @@ sub search : Global {
         # Store goods to be used in search results listing
         # NOTE: $page->path is '/' for app root,
         # but $c->request->path is empty for app root.
-        my ( $title_base_nodes, $title_terminal_node );
-        my $link_title =
-          $page->path;
-        if ( $page->path eq '/' ) {
-            $title_base_nodes    = $EMPTY_STRING;
-            $title_terminal_node = '/';
-        }
-        else {
-            ( $title_base_nodes, $title_terminal_node ) =
-              $page->path =~ m{(.*/)(.*)$};
-              $title_base_nodes =~ s{^/}{};
+        my $title_base_nodes;
+        if ( $page->path ne '/' ) {
+            ( $title_base_nodes ) =
+              $page->path =~ m{(.*/).*$};
+            $title_base_nodes =~ s{^/}{};
             $title_base_nodes =~ s{/}{ > }g;
-            $title_terminal_node = ucfirst($title_terminal_node);
         }
         $results_hash{ $hit->{path} } = {
             snippet             => $snippet->as_html,
             page                => $page,
             score               => $hit->{score},
-            link_title          => $link_title,
             title_base_nodes    => $title_base_nodes,
-            title_terminal_node => $title_terminal_node
         };
 
     }
@@ -229,6 +216,7 @@ sub search : Global {
         $c->stash->{results}       = $results;
         $c->stash->{result_count}  = $result_count;
     }
+    $stash->{template} = 'page/search.tt';
 }
 
 =head2 print
@@ -243,6 +231,13 @@ sub print : Global {
     $c->forward('view');
 }
 
+sub inline : Global {
+    my ( $self, $c, $page ) = @_;
+    $c->stash->{template} = 'page/inline.tt';
+    $c->forward('view');
+}
+
+
 =head2 inline_tags (.inline_tags)
 
 Tag list for the bottom of page views.
@@ -278,7 +273,22 @@ sub list : Global {
     $c->stash->{tags} = $c->model("DBIC::Tag")->most_used();
     $c->detach('/tag/list') if $tag;
     $c->stash->{template} = 'page/list.tt';
-    $c->stash->{pages}    = [ $page->descendants ];
+    
+    if ( $c->pref('check_permission_on_view') ) {
+      my $user;
+      my @pages;
+      my @all_pages = $page->descendants;
+      if ( $c->user_exists() ) { $user = $c->user->obj; }
+      foreach my $page_to_check (@all_pages) {
+        # skip pages without view permissions
+        my $perms = $c->check_permissions( $page_to_check->path, $user );
+        next unless $perms->{'view'};
+        push @pages,$page_to_check;
+      }
+      $c->stash->{pages}    = [ @pages ];
+    } else {
+      $c->stash->{pages}    = [ $page->descendants ];
+    }
 
     # FIXME - real data here please
     $c->stash->{orphans} = [];
@@ -346,7 +356,7 @@ sub atom : Global {
     $c->stash->{template} = 'page/atom.tt';
 }
 
-=head2 rss_full (.rss_full) 
+=head2 rss_full (.rss_full)
 
 Full content RSS feed of recent nodes in this namespace.
 
@@ -412,7 +422,7 @@ Marcus Ramberg <mramberg@cpan.org>
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify
+This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
