@@ -3,6 +3,7 @@ use warnings;
 use strict;
 use Data::Dumper;
 use base 'Catalyst::Controller::HTML::FormFu';
+use Syntax::Highlight::Engine::Kate;
 
 =head1 NAME
 
@@ -43,8 +44,8 @@ sub auto : Private {
 =head2 edit
 
 This action will display the edit form, then save the previous
-revision, and create a new based on the posted content.
-after saving, it will forward to the highlight action.
+revision, and create a new one based on the posted content.
+After saving, it will forward to the highlight action.
 
 =cut
 
@@ -68,7 +69,7 @@ sub edit : Global FormConfig {
     }
 
     # the page we're editing is at the end of either path_pages or
-    # proto_pages, # depending on whether or not the page already exists
+    # proto_pages, depending on whether or not the page already exists
     my $page = (
           @$proto_pages > 0
         ? $proto_pages->[ @$proto_pages - 1 ]
@@ -83,20 +84,31 @@ sub edit : Global FormConfig {
       $c->check_permissions( $stash->{'path'},
         ( $c->user_exists ? $c->user->obj : undef ) );
     my $permtocheck = ( @$proto_pages > 0 ? 'create' : 'edit' );
+    my $loc_permtocheck=$permtocheck eq 'create'?$c->loc('create'):$c->loc('edit');
     if ( !$perms->{$permtocheck} ) {
         my $name = ref($page) eq 'HASH' ? $page->{name} : $page->name;
-        $stash->{'message'} =
-          $c->loc( 'Permission Denied to x x', [ $permtocheck, $name ] );
-        $stash->{'template'} = 'message.tt';
+        $stash->{message} =
+          $c->loc( 'Permission Denied to x x', [ $loc_permtocheck, $name ] );
+        $stash->{template} = 'message.tt';
         return;
     }
     if ( $user == 1 && !$c->pref('anonymous_user') ) {
-        $c->stash->{message} ||= 'Anonymous Edit disabled';
+        $c->stash->{message} ||= $c->loc('Anonymous Edit disabled');
         return;
     }
 
+    # for anonymous users, use CAPTCHA, if enabled
+    if ( $user == 1 && $c->pref('use_captcha') ) {
+       my $captcha_lang= $c->session->{lang} || $c->pref('default_lang') ;
+       $c->stash->{captcha}=$form->element({ type=>'reCAPTCHA', name=>'captcha', recaptcha_options=>{ lang => $captcha_lang , theme=>'white' } });
+       $form->process;
+    }
+
+    my $syntax=new Syntax::Highlight::Engine::Kate;
+    $c->stash->{syntax_formatters}=[ $syntax->languageList() ];
+
     if ( $form->submitted_and_valid ) {
-        
+
 
         my $valid = $form->params;
         $valid->{creator} = $user;
@@ -109,16 +121,16 @@ sub edit : Global FormConfig {
                 creator     => $user,
             );
             $page = $path_pages->[ @$path_pages - 1 ];
-        } 
-            
-        $stash->{content}=$page->content;
+        }
+
+        $stash->{content} = $page->content;
         $c->model("DBIC::Page")->set_paths(@$path_pages);
 
 # refetch page to have ->content available, else it will break in DBIC 0.08099_05 and later
         #$page = $c->model("DBIC::Page")->find( $page->id );
         $page->discard_changes;
 
-        if( $c->stash->{content} && 
+        if( $c->stash->{content} &&
             $c->req->params->{version} != $c->stash->{content}->version ) {
             $c->stash->{message}=$c->loc('Someone else changed the page while you edited. Your changes has been merged. Please review and save again');
             my $orig_content = $c->model("DBIC::Content")->find(
@@ -127,7 +139,7 @@ sub edit : Global FormConfig {
                     version => $c->req->params->{version},
                 }
             );
-            $c->stash->{merged_body}||=$orig_content->merge_content(
+            $c->stash->{merged_body} ||= $orig_content->merge_content(
                 $c->stash->{content},
                 $form->params->{body},
                 $c->loc('THEIR CHANGES'),
@@ -148,7 +160,7 @@ sub edit : Global FormConfig {
 
         # Redirect back to edits or view page mode.
         my $redirect = $c->uri_for( $c->stash->{path} );
-        if ( $form->params->{submit} eq 'Save' ) {
+        if ( $form->params->{submit} eq $c->localize('Save') ) {
             $redirect .= '.edit';
             if ( $c->req->params->{split} &&
                  $c->req->params->{'split'} eq 'vertical' ) {
@@ -280,7 +292,7 @@ Marcus Ramberg <mramberg@cpan.org>
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify 
+This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
