@@ -42,7 +42,7 @@ default action - serve the home node
 sub default : Path {
     my ( $self, $c ) = @_;
     $c->res->status(404);
-    $c->stash->{message} = $c->loc("The requested URL (x) was not found", 
+    $c->stash->{message} = $c->loc("The requested URL (x) was not found",
                                $c->stash->{pre_hacked_uri});
     $c->stash->{template} = 'message.tt';
 }
@@ -74,13 +74,23 @@ sub render : ActionClass('RenderView') {
 =item end (builtin)
 
 At the end of any request, forward to view unless there is a template
-or response. then render the template. If param 'die' is passed, 
+or response, then render the template. If param 'die' is passed,
 show a debug screen.
 
 =cut
 
 sub end : Private {
     my ( $self, $c ) = @_;
+
+    my $theme=$c->pref('theme');
+    # if theme doesn't exist
+    if ( ! -d  $c->path_to('root','static','themes',$theme)) {
+       $theme='default';
+       $c->pref('theme',$theme);
+    }
+    $c->stash->{additional_template_paths} =
+        [ $c->path_to('root','themes',$theme) ];
+
     $c->req->uri->path( $c->stash->{pre_hacked_uri}->path )
         if ref $c->stash->{pre_hacked_uri};
     $c->forward('render');
@@ -88,17 +98,14 @@ sub end : Private {
 
 =item auto
 
-runs for all requests, checks if user is in need of validation, and 
+Runs for all requests, checks if user is in need of validation, and
 intercepts the request if so.
 
 =cut
 
 sub auto : Private {
     my ( $self, $c ) = @_;
-    if ( defined $c->config->{permissions}{enforce_login}
-        and $c->config->{permissions}{enforce_login} )
-    {
-
+    if ( $c->pref('enforce_login') ) {
         # allow a few actions
         if ( grep $c->action->name eq $_, qw/login logout recover_pass register/ ) {
             return 1;
@@ -114,11 +121,25 @@ sub auto : Private {
     $c->stash->{template} = 'user/validate.tt';
 }
 
+sub exit : Local {
+    my ($self, $c) = @_;
+    if ($ENV{MOJOMOJO_EXIT_OK}) {
+        exit(0);
+    }
+    else {
+       # $c->stash( template => 'error.tt' );
+        $c->res->status (403); # forbidden
+        $c->res->body('EXIT NOT OK');
+        $c->detach();
+    }
+}
+
+
 =back
 
 =head1 LICENSE
 
-This library is free software . You can redistribute it and/or modify 
+This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
