@@ -3,7 +3,6 @@ package MojoMojo::Formatter::Scrub;
 use base qw/MojoMojo::Formatter/;
 
 use HTML::Scrubber;
-use XML::Clean;
 
 =head1 NAME
 
@@ -11,7 +10,7 @@ MojoMojo::Formatter::Scrub - Scrub user HTML
 1
 =head1 DESCRIPTION
 
-This formatter makes sure only a safe range of tags are 
+This formatter makes sure only a safe range of tags are
 allowed, using L<HTML::Scrubber>; It also makes sure all tags
 are balaced, using L<XML::Clean>.
 
@@ -21,20 +20,31 @@ are balaced, using L<XML::Clean>.
 
 =item format_content_order
 
-Format order can be 1-99. The Comment formatter runs on 1
+Format order can be 1-99. The Scrub formatter runs on 7
+in order to catch direct user input, but trusts all subsequently
+ran plugins to not output unsafe HTML.
 
 =cut
 
 sub format_content_order { 7 }
 
-my @allow = qw[ p img em br hr b a div pre code];
+my @allow = qw[ p img em br hr b a div pre code span];
 
 my @rules = (
     script => 0,
+    div    =>  {
+        class => 1,
+        style => 1,
+    },
+    span    => {
+        class => 1,
+        style => 1,
+    },
     img    => {
-        src => qr{^(?!http://)}i,    # only relative image links allowed
-        alt => 1,                    # alt attribute allowed
-        '*' => 0,                    # deny all other attributes
+        class => 1,
+        src   => qr{^(?!http://)}i,    # only relative image links allowed
+        alt   => 1,                    # alt attribute allowed
+        '*'   => 0,                    # deny all other attributes
     },
 );
 
@@ -86,14 +96,9 @@ context object.
 =cut
 
 sub format_content {
-    return 0;
     my ( $class, $content, $c ) = @_;
     $$content = $scrubber->scrub($$content);
     return 1;
-
-    #FIXME: XML::Clean doubles the first word in previews
-    # but makes sure all divs are matched.
-    $$content = XML::Clean::clean($$content);
 }
 
 =back
