@@ -3,14 +3,19 @@ package MojoMojo::Formatter::SyntaxHighlight;
 use strict;
 use warnings;
 use base qw/MojoMojo::Formatter/;
-use Syntax::Highlight::Engine::Kate;
 use HTML::Entities;
 
+eval "use Syntax::Highlight::Engine::Kate;";
+my $eval_res=$@;
+
+sub module_loaded { $eval_res ? 0 : 1 }
+
+
 my $main_formatter;
 eval {
     $main_formatter = MojoMojo->pref('main_formatter');
 };
-$main_formatter ||= 'MojoMojo::Formatter::Textile';
+$main_formatter ||= 'MojoMojo::Formatter::Markdown';
 
 =head1 NAME
 
@@ -18,9 +23,7 @@ MojoMojo::Formatter::SyntaxHighlight - syntax highlighting for code blocks
 
 =head1 DESCRIPTION
 
-This formatter performs syntax highlighting on code blocks. Unfortunately
-this currently works only if you're using L<MojoMojo::Formatter::Textile>
-as main formatter.
+This formatter performs syntax highlighting on code blocks.
 
 =head1 METHODS
 
@@ -40,41 +43,48 @@ sub format_content_order { 99 }
 =item format_content
 
 This formatter uses L<Syntax::Highlight::Engine::Kate> to highlight code
-syntax inside of E<lt>preE<gt> tags. To let the formatter know which language
+syntax inside of <pre lang="my_lang"> </pre>tags. To let the formatter know which language
 has to be highlighted, do:
 
  <pre lang="Perl">
-   print "Hello World\n";
- </pre>
+   say "Hola Mundo";
+ </pre> 
 
 See L<Syntax::Highlight::Engine::Kate/PLUGINS> for a list of supported
 languages.
 
 =cut
 
+# NOTE: Moved $kate outside of format_content method because
+# of apparent memory links so we want to re-use the object instead
+# of creating a new one each time a page is requested.
+my $kate = _kate();
+
 sub format_content {
     my ( $class, $content ) = @_;
-    
-    # No syntax highlighting for anything else than Textile yet, SORRY
-    unless ($main_formatter eq 'MojoMojo::Formatter::Textile') {
-        $$content =~ s/<\s*pre\s+lang=".*?"\s*>/<pre>/g;
-        return $$content;
-    }
-
-    $$content = decode_entities($$content);
+    return unless $class->module_loaded;
 
     my @blocks  = ();
-    my $kate    = _kate();
     my $ph      = 0;
     my $ph_base = __PACKAGE__ . '::PlaceHolder::';
-    
+
+    # new school - consistent with other new syntax, but broke for me to the point of exhaustion
+    # $$content =~ s/\{\{\s*code\s+lang=""\s*\}\}/<pre>/g;
+    # while ( $$content =~ s/\{\{\s*code(?:\s+lang=['"]*(.*?)['"]*")?\s*\}\}(.*?)\{\{\s*end\s*\}\}/$ph_base$ph/si ) {
+    # old school - which works with textile2 (not textile for mxh)
     # drop all lang=""
     $$content =~ s/<\s*pre\s+lang=""\s*>/<pre>/g;
-    
     while ( $$content =~ s/<\s*pre(?:\s+lang=['"]*(.*?)['"]*")?\s*>(.*?)<\s*\/pre\s*>/$ph_base$ph/si ) {
         my ($language, $block) = ($1, $2);
         # Fix newline issue
         $block =~ s/\r//g;
+
+        # Unfortunately markdown also encodes entities at some level which is not possible to disable
+        # neither easy to hack like we do for textile. So let's decode &amp; to & to avoid:
+        # &gt; => &amp;gt;
+        $block =~ s/&amp;/&/g;
+
+        $block = decode_entities($block);
         if ($language) {
             eval {
                 $kate->language($language);
@@ -86,11 +96,11 @@ sub format_content {
         push @blocks, $block;
         $ph++;
     }
-    
+
     for (my $i=0; $i<$ph; $i++) {
         $$content =~ s/$ph_base$i/<pre>$blocks[$i]<\/pre>/;
     }
-    
+
     return $content;
 }
 
@@ -98,9 +108,6 @@ sub _kate {
     return Syntax::Highlight::Engine::Kate->new(
         language      => 'Perl',
         substitutions => {
-            "<"  => "&lt;",
-            ">"  => "&gt;",
-            "&"  => "&amp;",
             " "  => "&nbsp;",
             "\t" => "&nbsp;&nbsp;&nbsp;",
             "\n" => "\n",
