@@ -12,7 +12,7 @@ use MojoMojo;
 
 my $help = 0;
 my ( $listen, $nproc, $pidfile, $manager, $detach, $keep_stderr );
- 
+
 GetOptions(
     'help|?'      => \$help,
     'listen|l=s'  => \$listen,
@@ -25,10 +25,10 @@ GetOptions(
 
 pod2usage(1) if $help;
 
-MojoMojo->run( 
-    $listen, 
+MojoMojo->run(
+    $listen,
     {   nproc   => $nproc,
-        pidfile => $pidfile, 
+        pidfile => $pidfile,
         manager => $manager,
         detach  => $detach,
 	keep_stderr => $keep_stderr,
@@ -44,7 +44,7 @@ mojomojo_fastcgi.pl - Catalyst FastCGI
 =head1 SYNOPSIS
 
 mojomojo_fastcgi.pl [options]
- 
+
  Options:
    -? -help      display this help and exits
    -l -listen    Socket path to listen on
@@ -67,10 +67,9 @@ mojomojo_fastcgi.pl [options]
 
 Run a Catalyst application as fastcgi.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Sebastian Riedel, C<sri@oook.de>
-Maintained by the Catalyst Core Team.
+Catalyst Contributors, see Catalyst.pm
 
 =head1 COPYRIGHT
 
