@@ -66,26 +66,31 @@ sub init_schema {
         __PACKAGE__->populate_schema( $schema ) if( !$args{no_populate} );
     }
     my $config = {
-	name => 'MojoMojo Test Suite',
-	'Model::DBIC' => {
-	    connect_info => [ $dsn ],
-	},    authentication => {
-            default_realm=> 'members',
-            use_session => 1,
-            realms => {
+       name => 'MojoMojo Test Suite',
+       'Model::DBIC' => {
+           connect_info => [ $dsn ],
+       },
+       authentication => {
+           default_realm => 'members',
+           use_session => 1,
+           realms => {
                 members => {
-                    credential =>{
-                        class=> 'Password',
-                        password_field=> 'pass',
-                        password_type=> 'hashed',
-                        password_hash_type=> 'SHA-1'},
+                    credential => {
+                        class => 'Password',
+                        password_field => 'pass',
+                        password_type => 'hashed',
+                        password_hash_type => 'SHA-1'
+                    },
                     store => {
-                        class=> 'DBIx::Class',
-                        user_class=> 'DBIC::Person',
-        }   }   }   }
+                        class => 'DBIx::Class',
+                        user_class => 'DBIC::Person',
+                    }
+                }
+           }
+        }
     };
     YAML::DumpFile('t/var/mojomojo.yml',$config);
-    
+
 
     return $schema;
 }
@@ -146,4 +151,3 @@ sub create_test_data {
 }
 
 1;
-
